@@ -484,7 +484,7 @@ void KMixWindow::loadBaseConfig()
     m_showTicks = config.readEntry("Tickmarks", true);
     m_showLabels = config.readEntry("Labels", true);
     m_onLogin = config.readEntry("startkdeRestore", true );
-    m_beepOnVolumeChange = config.readEntry("VolumeFeedback", false );
+    setBeepOnVolumeChange(config.readEntry("VolumeFeedback", false ));
     m_startVisible = config.readEntry("Visible", false);
     m_multiDriverMode = config.readEntry("MultiDriver", false);
     const QString& orientationString = config.readEntry("Orientation", "Vertical");
